##
# name:      Foo::Bar
# abstract:  Best Foo module ever
# author:    Ingy döt Net <ingy@cpan.org>
# license:   perl
# copyright: 2012

use 5.010;
use strict;
use warnings;

package Foo::Bar;

our $VERSION = '0.10';

1;

=head1 SYNOPSIS

...

=head1 DESCRIPTION

...
